Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Interval ¶
Interval defines the interval type
func (*Interval) Before ¶
Before return true if the interval started before other, or if start times are the same and it end before other, false otherwise
func (*Interval) Close ¶
func (i *Interval) Close()
Closes closes the interval by setting its end date to time.Now()
func (*Interval) Duration ¶
Duration returns the total duration of the interval. If the interval is not closed, it will return the currently elapsed time.
type SortByDate ¶
type SortByDate []Interval
SortByDate defines an interval slice that can be sorted by the interval dates
Click to show internal directories.
Click to hide internal directories.